@@ -16,17 +16,17 @@ sub lngbase {
  ,-nup=>['Up',     'An upper level']
  ,-nth=>['Reset',  'This application default']
  ,-bck=>['Back',   'Back to previous screen']
- ,-lgn=>['Guest',  'Login to the System']
- ,-lst=>['List',   'List records under query condition']
+ ,-lgn=>['Login',  'Login to the System']
+ ,-lst=>['List',   'List records, select records under query condition']
  ,-lsr=>['List',   'List records']
  ,-qry=>['Query',  'Query condition to list records by']
  ,-crt=>['New',    'New record creation to insert it to the database']
- ,-sel=>['Select', '(Re)read data from database, select record']
+ ,-sel=>['Read',   '(Re)read data from database, select record; escape edit mode discarding changes']
  ,-prn=>['Print',  'Printable form']
- ,-edt=>['Edit',   'Edit mode toggle']
+ ,-edt=>['Edit',   'Edit mode switch']
  ,-frm=>['Form',   'Form reload and review, data recalculation']
- ,-upd=>['Update', 'Update this record in the database, save changes of this record']
- ,-del=>['Delete', 'Delete this record from the database']
+ ,-upd=>['Update', 'Update record in the database, save changes of this record']
+ ,-del=>['Delete', 'Delete record from the database']
  ,-ins=>['Insert', 'Insert new record into database']
  ,-hlp=>['Help',   'Open Help screen']
 
@@ -34,7 +34,7 @@ sub lngbase {
  ,'!constr' => ['',       'Constraint violations']
 
  ,'Help'     =>['Help',         '']
- ,'Lists'    =>['Views (Lists)','Views (Lists of records) defined by application']
+ ,'Lists'    =>['Views',	'Views (lists of records) defined by application']
  ,'Fields'   =>['Fields',       'Data fields defined by application']
  ,'Commands' =>['Commands',     'Commands may be used']
  )
